@@ -3,8 +3,6 @@ context("filterDate")
 test_that("filterDate", {
     text <- as.list(paste("text", 1:200))
     names(text) <- paste("id", 101:300)
-    suppressWarnings(RNGversion("3.5.0"))
-    set.seed(24601)
     meta <- data.frame(
       id = paste("id", 1:400),
       date = as.Date(1:400, origin="1990-10-03"),
